==> kom%2B%2B-0.3.tar.gz: kom++-0.3/libkom++/map-cache.h <==
// Create-on-demand map of mappings for conferences.
//
// $Id: map-cache.h,v 1.3 1994/07/16 17:44:20 ceder Exp $
// Copyright (C) 1994  Per Cederqvist and Inge Wallin
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

#ifndef MAP_CACHE__
#define MAP_CACHE__

#include "kom-types.h"
#include "misc.h"
#include "map-cache.h"
#include "Conf_no.Text_mapping.CHMap.h"

class Map_cache {
  public:
    Map_cache(const Conferences &c);
    Map_cache(const Map_cache&);
    Map_cache& operator=(const Map_cache&);
    ~Map_cache();

    // Methods working on the entire cache:
    void        clear();
    Connection *connection() const;

    // Methods working on individual conf-stats.
    Text_mapping   get(Conf_no cno);

  private:
    class Mtmap : private Conf_noText_mappingCHMap {
      public:
	Bool present(Conf_no p) const;
	Text_mapping &operator[](Conf_no p);
	Mtmap();
    };

    Connection  *m_conn;
    Conf_cache  *m_conf_cache;
    Mtmap        mapmap;
};

#endif

==> kom%2B%2B-0.5.tar.gz: kom++-0.5/libkom++/map-cache.h <==
// Create-on-demand map of mappings for conferences.
//
// $Id: map-cache.h,v 1.6 1995/11/18 22:49:42 ceder Exp $
// Copyright (C) 1994  Per Cederqvist and Inge Wallin
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

#ifndef KOMXX_MAP_CACHE_H
#define KOMXX_MAP_CACHE_H

#include "async.h"
#include "kom-types.h"
#include "misc.h"
#include "map-cache.h"
#include "Conf_no.Text_mapping.CHMap.h"

class Async_text_created;

class Map_cache {
  public:
    Map_cache(const Conferences &c, Async_dispatcher *async_disp);
    Map_cache(const Map_cache&);
    Map_cache& operator=(const Map_cache&);
    ~Map_cache();

    // Methods working on the entire cache:
    void        clear();
    Connection *connection() const;

    // Methods working on individual conf-stats.
    Text_mapping   get(Conf_no cno);

    // The cache automatically registers this callback method with the
    // Async_dispatcher.  This method should not be used in any other
    // way.
    void        new_text(const Async_text_created &msg);

  private:
    class Mtmap : private Conf_noText_mappingCHMap {
      public:
	bool present(Conf_no p) const;
	Text_mapping &operator[](Conf_no p);
	Mtmap();
    };

    Connection  *m_conn;
    Conf_cache  *m_conf_cache;
    Async_dispatcher *async_disp;
    Async_handler_tag<Async_text_created> cr_tag;

    Mtmap        mapmap;
};

#endif
